@@ -565,11 +565,21 @@ CREATE TABLE IF NOT EXISTS backup_history (
     id INT AUTO_INCREMENT PRIMARY KEY,
     target_id INT NOT NULL,
     user VARCHAR(50) NOT NULL,
-    backup_type ENUM('site', 'userfiles', 'database', 'wordpress') NOT NULL,
+    backup_type ENUM('site', 'userfiles', 'database', 'wordpress', 'all') NOT NULL,
     backup_name VARCHAR(255) NOT NULL,
     backup_path VARCHAR(500) NOT NULL,
+    local_path varchar(500) DEFAULT NULL COMMENT 'Path to local backup file',
+    local_size bigint DEFAULT NULL COMMENT 'Size of local backup file',
     backup_size BIGINT DEFAULT 0,
-    status ENUM('pending', 'running', 'completed', 'failed', 'deleted') NOT NULL DEFAULT 'pending',
+    upload_method enum('single','multipart') DEFAULT 'single',
+    multipart_upload_id varchar(255) DEFAULT NULL,
+    status ENUM('pending', 'claimed', 'running', 'completed', 'failed', 'deleted') NOT NULL DEFAULT 'pending',
+    creation_status enum('pending','creating','created','failed') DEFAULT 'pending' COMMENT 'Status of local backup creation',
+    upload_status enum('pending','uploading','uploaded','failed','skipped') DEFAULT NULL COMMENT 'Status of remote upload',
+    upload_started_at timestamp NULL DEFAULT NULL,
+    upload_completed_at timestamp NULL DEFAULT NULL,
+    upload_attempts int DEFAULT 0 COMMENT 'Number of upload attempts',
+    local_deleted_at timestamp NULL DEFAULT NULL COMMENT 'When local file was deleted',
     error_message TEXT DEFAULT NULL,
     started_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
     completed_at TIMESTAMP NULL DEFAULT NULL,
@@ -578,7 +588,11 @@ CREATE TABLE IF NOT EXISTS backup_history (
     INDEX idx_user (user),
     INDEX idx_status (status),
     INDEX idx_started_at (started_at),
-    INDEX idx_target_user (target_id, user)
+    INDEX idx_target_user (target_id, user),
+    INDEX idx_multipart_upload_id (multipart_upload_id),
+    INDEX idx_creation_status (creation_status),
+    INDEX idx_upload_status (upload_status),
+    INDEX idx_local_deleted (local_deleted_at)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 
 -- Create backup schedules table
@@ -586,7 +600,7 @@ CREATE TABLE IF NOT EXISTS backup_schedules (
     id INT AUTO_INCREMENT PRIMARY KEY,
     user VARCHAR(255) NOT NULL,
     target_id INT NOT NULL,
-    backup_type ENUM('site', 'userfiles', 'database', 'all') NOT NULL COMMENT 'Backup type - site type auto-detects WordPress sites for combined backup',
+    backup_type ENUM('site', 'userfiles', 'database', 'wordpress', 'all') NOT NULL COMMENT 'Backup type - site type auto-detects WordPress sites for combined backup',
     resource_name VARCHAR(255) DEFAULT NULL COMMENT 'Optional: specific site domain or database name. If NULL, backs up first available resource',
     schedule_type ENUM('daily', 'weekly', 'monthly') NOT NULL,
     schedule_time TIME NOT NULL DEFAULT '02:00:00',
@@ -608,7 +622,7 @@ CREATE TABLE IF NOT EXISTS backup_queue (
     id INT AUTO_INCREMENT PRIMARY KEY,
     target_id INT NOT NULL,
     user VARCHAR(50) NOT NULL,
-    backup_type ENUM('site', 'userfiles', 'database') NOT NULL,
+    backup_type ENUM('site', 'userfiles', 'database', 'wordpress', 'all') NOT NULL,
     backup_name VARCHAR(255) NOT NULL,
     priority ENUM('low', 'normal', 'high') DEFAULT 'normal',
     status ENUM('queued', 'processing', 'completed', 'failed') DEFAULT 'queued',
@@ -622,6 +636,73 @@ CREATE TABLE IF NOT EXISTS backup_queue (
     INDEX idx_user (user)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 
+-- Create multipart uploads tracking table
+CREATE TABLE IF NOT EXISTS multipart_uploads (
+    id int(11) NOT NULL AUTO_INCREMENT,
+    backup_id int(11) NOT NULL,
+    upload_id varchar(255) NOT NULL,
+    bucket varchar(255) NOT NULL,
+    key varchar(500) NOT NULL,
+    file_path varchar(500) NOT NULL,
+    file_size bigint NOT NULL,
+    chunk_size int NOT NULL,
+    total_parts int NOT NULL,
+    completed_parts text DEFAULT NULL COMMENT 'JSON array of completed part ETags',
+    status enum('in_progress','completed','aborted','failed') DEFAULT 'in_progress',
+    started_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
+    updated_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    completed_at timestamp NULL DEFAULT NULL,
+    PRIMARY KEY (id),
+    KEY idx_backup_id (backup_id),
+    KEY idx_upload_id (upload_id),
+    KEY idx_status (status),
+    KEY idx_started_at (started_at),
+    KEY idx_stale_uploads (status, updated_at),
+    CONSTRAINT fk_multipart_backup FOREIGN KEY (backup_id) REFERENCES backup_history (id) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
+-- Create backup upload queue table
+CREATE TABLE IF NOT EXISTS backup_upload_queue (
+    id int(11) NOT NULL AUTO_INCREMENT,
+    backup_id int(11) NOT NULL,
+    priority int DEFAULT 5 COMMENT 'Upload priority (1=highest, 10=lowest)',
+    status enum('queued','processing','completed','failed','cancelled') DEFAULT 'queued',
+    worker_id varchar(100) DEFAULT NULL COMMENT 'ID of worker processing this upload',
+    started_at timestamp NULL DEFAULT NULL,
+    completed_at timestamp NULL DEFAULT NULL,
+    error_message text DEFAULT NULL,
+    retry_count int DEFAULT 0,
+    next_retry_at timestamp NULL DEFAULT NULL,
+    created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
+    updated_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    PRIMARY KEY (id),
+    UNIQUE KEY uk_backup_id (backup_id),
+    KEY idx_status_priority (status, priority),
+    KEY idx_worker_id (worker_id),
+    KEY idx_next_retry (next_retry_at),
+    CONSTRAINT fk_upload_queue_backup FOREIGN KEY (backup_id) REFERENCES backup_history (id) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
+-- Create backup local storage management table
+CREATE TABLE IF NOT EXISTS backup_local_storage (
+    id int(11) NOT NULL AUTO_INCREMENT,
+    storage_path varchar(500) NOT NULL COMMENT 'Base path for local backup storage',
+    max_size_gb int DEFAULT 100 COMMENT 'Maximum storage size in GB',
+    current_size_bytes bigint DEFAULT 0 COMMENT 'Current used space in bytes',
+    cleanup_policy enum('immediate','after_upload','age_based','size_based') DEFAULT 'after_upload',
+    retention_hours int DEFAULT 24 COMMENT 'Hours to keep local backups (for age_based)',
+    low_watermark_gb int DEFAULT 80 COMMENT 'Start cleanup when this size reached (for size_based)',
+    is_active tinyint(1) DEFAULT 1,
+    created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
+    updated_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    PRIMARY KEY (id),
+    KEY idx_active (is_active)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
+-- Insert default local storage configuration
+INSERT INTO backup_local_storage (storage_path, max_size_gb, cleanup_policy, retention_hours)
+VALUES ('/docker/backups/local', 100, 'after_upload', 24);
+
 -- ================================================
 -- WORDPRESS MANAGEMENT TABLES
 -- ================================================
@@ -1058,6 +1139,111 @@ CREATE TABLE IF NOT EXISTS postgresql_user_database_access (
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
 
 
+-- WordPress Update Queue Table (from migration 2025.09.19)
+CREATE TABLE IF NOT EXISTS wp_update_queue (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    site_id INT NOT NULL,
+    update_id INT NOT NULL,
+    update_type VARCHAR(20) NOT NULL COMMENT 'core, plugins, themes, all',
+    backup_id INT DEFAULT NULL COMMENT 'ID of backup that must complete first',
+    status ENUM('waiting_for_backup', 'ready', 'processing', 'completed', 'failed') DEFAULT 'waiting_for_backup',
+    error_message TEXT DEFAULT NULL,
+    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+    started_at TIMESTAMP NULL DEFAULT NULL,
+    completed_at TIMESTAMP NULL DEFAULT NULL,
+
+    INDEX idx_status (status),
+    INDEX idx_backup_id (backup_id),
+    INDEX idx_site_id (site_id),
+    INDEX idx_created_at (created_at),
+
+    FOREIGN KEY (site_id) REFERENCES wordpress_sites(id) ON DELETE CASCADE,
+    FOREIGN KEY (update_id) REFERENCES wp_update_history(id) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
+-- Delegated Users System (from migration 2025.08.62)
+CREATE TABLE IF NOT EXISTS delegated_users (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    username VARCHAR(32) NOT NULL UNIQUE,
+    password_hash VARCHAR(255) NOT NULL,
+    parent_user VARCHAR(32) NOT NULL COMMENT 'The main user who created this delegated account',
+    display_name VARCHAR(100) DEFAULT NULL,
+    permissions JSON DEFAULT NULL COMMENT 'Specific permissions granted to this user',
+    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    last_login_at TIMESTAMP NULL DEFAULT NULL,
+    is_active BOOLEAN DEFAULT TRUE,
+
+    INDEX idx_parent_user (parent_user),
+    INDEX idx_username (username),
+    INDEX idx_active (is_active)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
+-- Delegated user sessions (from migration 2025.08.67)
+CREATE TABLE IF NOT EXISTS delegated_user_sessions (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    session_id VARCHAR(64) NOT NULL UNIQUE,
+    username VARCHAR(32) NOT NULL,
+    parent_user VARCHAR(32) NOT NULL,
+    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+    last_activity TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+    expires_at TIMESTAMP NOT NULL,
+    ip_address VARCHAR(45),
+    user_agent TEXT,
+
+    INDEX idx_session_id (session_id),
+    INDEX idx_username (username),
+    INDEX idx_expires_at (expires_at),
+
+    FOREIGN KEY (username) REFERENCES delegated_users(username) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
+-- Permissions System (from migration 001_backup_system.sql and others)
+CREATE TABLE IF NOT EXISTS permissions (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    name VARCHAR(100) NOT NULL UNIQUE,
+    description TEXT,
+    category VARCHAR(50) DEFAULT 'general',
+    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+CREATE TABLE IF NOT EXISTS user_permissions (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    username VARCHAR(32) NOT NULL,
+    permission_id INT NOT NULL,
+    granted_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+    granted_by VARCHAR(32) DEFAULT NULL,
+    UNIQUE KEY unique_user_permission (username, permission_id),
+    FOREIGN KEY (permission_id) REFERENCES permissions(id) ON DELETE CASCADE,
+    INDEX idx_username (username)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+-- Add backup permissions
+INSERT INTO permissions (name, description, category) VALUES
+    ('backup_manage_global', 'Manage global backup targets', 'backup'),
+    ('backup_view_all', 'View all user backups', 'backup'),
+    ('backup_download_all', 'Download all user backups', 'backup'),
+    ('backup_delete_all', 'Delete all user backups', 'backup'),
+    ('backup_manage_own', 'Manage own backup targets', 'backup'),
+    ('backup_create', 'Create backups', 'backup'),
+    ('backup_download_own', 'Download own backups', 'backup'),
+    ('backup_delete_own', 'Delete own backups', 'backup')
+ON DUPLICATE KEY UPDATE description = VALUES(description);
+
+-- Grant backup permissions to root
+INSERT INTO user_permissions (username, permission_id)
+SELECT 'root', id FROM permissions WHERE name IN (
+    'backup_manage_global',
+    'backup_view_all',
+    'backup_download_all',
+    'backup_delete_all',
+    'backup_manage_own',
+    'backup_create',
+    'backup_download_own',
+    'backup_delete_own'
+)
+ON DUPLICATE KEY UPDATE username = VALUES(username);
+
 -- ================================================
 -- SETUP COMPLETE
 -- ================================================
