@@ -155,7 +155,12 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
         if (empty($_SESSION['csrf_token'])) {
             $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
         }
-        
+
+        // Initialize theme preference if not set (default to auto/system preference)
+        if (!isset($_SESSION['theme_preference'])) {
+            $_SESSION['theme_preference'] = 'auto';
+        }
+
         // Record successful login and clear failed attempts
         $user_agent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
         $SecManager->record_successful_login($user_ip, $_POST["user"], $user_agent);
@@ -201,7 +206,12 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
             if (empty($_SESSION['csrf_token'])) {
                 $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
             }
-            
+
+            // Initialize theme preference if not set (default to auto/system preference)
+            if (!isset($_SESSION['theme_preference'])) {
+                $_SESSION['theme_preference'] = 'auto';
+            }
+
             // Redirect to index page
             header('Location: /index.php');
             exit();
@@ -295,6 +305,11 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
         if (empty($_SESSION['csrf_token'])) {
             $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
         }
+
+        // Initialize theme preference if not set (default to auto/system preference)
+        if (!isset($_SESSION['theme_preference'])) {
+            $_SESSION['theme_preference'] = 'auto';
+        }
     } else {
         error_log("Invalid nonce check result: " . print_r($nonce_check, true));
         // Redirect to login for security
